@@ -21,10 +21,10 @@ class Act():
         srcfile = os.path.join(os.path.dirname(backstage.__file__),'conf/uwsgi.ini.src')
         with open(srcfile,'r') as f:
             srcdata = f.read()
-        outfile = open(os.path.join(self.acthome,'uwsgi.ini','w'))
-        outfile.write(srcdata.format(VENUE_ROOT=self.venue.VENUE_ROOT,VENUE_NAME=self.venue.VENUE_NAME,ACT_NAME=self.actname))
-        outfile.close()
-        print srcdata
+        outfile = os.path.join(self.acthome,'uwsgi.ini')
+        o = open(outfile,'w')
+        o.write(srcdata.format(VENUE_ROOT=self.venue.VENUE_ROOT,VENUE_NAME=self.venue.VENUE_NAME,ACT_NAME=self.actname))
+        o.close()
 
 def new_act(venue, actname):
     """create a new Act within a backstage Venue"""
