@@ -8,7 +8,7 @@ from backstage.act.models import Act
 
 class Venue():
     """A backstage Venue is a specific local install of backstage."""
-    def __init__(self,venue_root):
+    def __init__(self, venue_root):
         """Initialize a Backstage Venue instance. Required arguments are the name of the venue and the fullpath of the venue (name included)
         """
         self.VENUE_ROOT = os.path.abspath(venue_root)
@@ -49,6 +49,7 @@ class Venue():
             return True
         except:
             return False
+
     def getallsites(self):
         """ create a dictionary of all sites, from the database """
         self.sites = {}
@@ -138,7 +139,7 @@ class Venue():
 
 def copy_venue_skel(venue_path):
     """Populate a (usually) new backstage venue with the contents of backstage/skel"""
-    skeldir = os.path.join(os.path.dirname(backstage.__file__),'skel')
+    skeldir = os.path.join(os.path.dirname(backstage.__file__),'skel/venue')
     if not os.path.exists(skeldir):
         s = 'Source skeleton files for backstage venue not found.  This is a system error'
         print s
